@@ -61,6 +61,8 @@ extern gchar*           game_name;
 extern gboolean         game_in_progress;
 extern gboolean         game_over;
 extern gboolean         game_won;
+extern gboolean         click_to_move;
+extern gchar            *gamesdir;
 
 extern guint            x_spacing;
 extern guint            y_spacing;
@@ -72,12 +74,13 @@ extern GConfClient * gconf_client;
 gchar* game_file_to_name(const gchar* file);
 void new_game(gchar* file, guint *seed);
 void quit_app (GtkMenuItem*);
-void set_score( void );
-void timer_start( void );
-void timer_stop( void );
+void set_score (void);
+void timer_start (void);
+void timer_restart (void);
+void timer_stop (void);
 void timer_reset (void);
 guint timer_get (void);
-void make_title( void );
+void make_title (void);
 void eval_installed_file(gchar *file);
 
 #endif
