@@ -2,7 +2,7 @@
 /*
  * Blackjack
  *
- * Copyright (C) 2003-2004 William Jon McCann <mccann@jhu.edu>
+ * Copyright (C) 2003-2005 William Jon McCann <mccann@jhu.edu>
  *
  * This game is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,34 +22,25 @@
 
 #include <config.h>
 
-#ifdef HAVE_ALLOCA_H
-#include <alloca.h>
-#endif
-
-#include <sys/types.h>
-#include <string.h>
 #include <stdlib.h>
-#include <dirent.h>
-#include <ctype.h>
 #include <glib/gi18n.h>
-
-#include "blackjack.h"
+#include <gtk/gtk.h>
+#include <gconf/gconf-client.h>
 
 #ifdef HAVE_GNOME
 #include <gnome.h>
 #endif
 
+#include "blackjack.h"
 #include "events.h"
 #include "draw.h"
 #include "slot.h"
 #include "card.h"
 #include "menu.h"
 #include "dialog.h"
-
 #include "game.h"
 #include "hand.h"
 
-#include <iostream>
 using namespace std;
 
 // Global Variables
@@ -80,8 +71,6 @@ guint            y_spacing = 15;
 double           x_expanded_offset = 0.21;
 double           y_expanded_offset = 0.21;
 
-gboolean         events_pending = false;
-
 static GConfClient *gconf_client = NULL;
 
 gfloat wager_value = 5.0;
@@ -332,6 +321,7 @@ create_main_window (void)
         gtk_ui_manager_add_ui_from_string (ui, ui_definition, -1, &error);
 
         actions = gtk_action_group_new ("Actions");
+        gtk_action_group_set_translation_domain (actions, GETTEXT_PACKAGE);
         gtk_action_group_add_actions (actions, entries, G_N_ELEMENTS (entries), toplevel_window);
         gtk_action_group_add_toggle_actions (actions, toggle_entries, G_N_ELEMENTS (toggle_entries), toplevel_window);
         gtk_ui_manager_insert_action_group (ui, actions, 0);
@@ -686,7 +676,7 @@ main (int argc, char *argv [])
 
         gtk_widget_push_colormap (gdk_rgb_get_colormap ());
 
-        gtk_window_set_default_icon_name ("gnome-blackjack");
+        gtk_window_set_default_icon_from_file (PIXMAPDIR"/gnome-blackjack.png", NULL);
 
         bj_gconf_init (bj_gconf_client ());
 
