@@ -4,7 +4,7 @@
  *
  * Time-stamp: <1999/01/18 18:50:24 carsten>
  *
- * Copyright (C) 1998, 1999 Carsten Schaar
+ * Copyright (C) 1998, 1999, 2003 Carsten Schaar
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -190,7 +190,9 @@ view_new (GdkPixbuf *curtain_image)
   view->view_buffer = NULL;
 
   /* Initialize curtain stuff.  */
-  gdk_pixbuf_render_pixmap_and_mask (curtain_image, &view->curtain_image, NULL, 127);
+  gdk_pixbuf_render_pixmap_and_mask_for_colormap (curtain_image, 
+						  gdk_colormap_get_system (),
+						  &view->curtain_image, NULL, 127);
   
   view->curtain_display_mode= CURTAIN_DISPLAY_CLOSING;
   view->curtain             = 0;
@@ -377,7 +379,7 @@ view_set_curtain_mode (GStonesView     *view,
 
   if (view->curtain_timeout)
     {
-      gtk_timeout_remove (view->curtain_timeout);
+      g_source_remove (view->curtain_timeout);
       view->curtain_timeout= 0;
     }
   
@@ -397,7 +399,7 @@ view_set_curtain_mode (GStonesView     *view,
 
 
       view->curtain_timeout= 
-	gtk_timeout_add (CURTAIN_DELAY, view_curtain_timeout, (gpointer) view);
+	g_timeout_add (CURTAIN_DELAY, view_curtain_timeout, (gpointer) view);
       break;
 
     case VIEW_CURTAIN_CLOSED:
