@@ -139,7 +139,8 @@ Tetris::Tetris(int cmdlLevel):
 	g_signal_connect (w, "delete_event", G_CALLBACK (gameQuit), this);
 	gtk_window_set_resizable (GTK_WINDOW (w), FALSE);
 	gtk_drag_dest_set (w, GTK_DEST_DEFAULT_ALL, targets, 
-			   G_N_ELEMENTS(targets), GDK_ACTION_MOVE);
+			   G_N_ELEMENTS(targets), 
+			   GDK_ACTION_MOVE);
 	g_signal_connect (G_OBJECT (w), "drag_data_received", 
 			  G_CALLBACK (dragDrop), this);
 
@@ -1011,7 +1012,7 @@ Tetris::timeoutHandler(void *d)
 		if (res)
 		{
 			t->manageFallen();
-			if(t->fastFall) {
+			if(t->fastFall && t->inPlay) {
 				t->scoreFrame->incScore(t->fastFallPoints);
 				t->fastFall = false;
 			}
@@ -1205,10 +1206,6 @@ Tetris::dragDrop(GtkWidget *widget, GdkDragContext *context,
 	
 	/* FIXME: We don't handle colour gradients (e.g. from the gimp) */
 
-	/* FIXME: Drag and drop from konqueror doesn't work, we
-	 * aren't even registering that it is providing test/uri-list
-	 * content. */
-
 	/* FIXME: Dropped URLs from mozilla don't work (see below). */
 
 	if (data->length < 0) {
@@ -1346,6 +1343,7 @@ Tetris::endOfGame()
 	color_next = -1;
 	blocknr_next = -1;
 	rot_next = -1;
+	gtk_widget_queue_draw(preview->getWidget());
         gnome_canvas_item_hide (pauseMessage);
         gnome_canvas_item_show (gameoverMessage);
         gnome_canvas_item_raise_to_top (gameoverMessage);
