@@ -532,6 +532,14 @@ load_pixmaps (void)
                                            tmp, FALSE, NULL);
 	g_free (tmp);
 
+	if (! g_file_test (fname, G_FILE_TEST_EXISTS)) {
+		g_free (fname);
+		fname = gnome_program_locate_file (NULL,
+						   GNOME_FILE_DOMAIN_APP_PIXMAP,
+		                                   "iagno/classic.png",
+						   FALSE, NULL);
+	}
+
 	if (! g_file_test (fname,
 			   G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR)) {
 		g_print (_("Could not find \'%s\' pixmap file\n"), fname);
@@ -545,8 +553,10 @@ load_pixmaps (void)
 		error = NULL;
 	}
 
-	gdk_pixbuf_render_pixmap_and_mask (image, &tiles_pixmap,
-					   &tiles_mask, 127);
+	gdk_pixbuf_render_pixmap_and_mask_for_colormap (image, 
+							gdk_colormap_get_system(),
+							&tiles_pixmap,
+							&tiles_mask, 127);
 
 	gdk_pixbuf_unref (image);
 	g_free (fname);
