@@ -74,6 +74,8 @@ gint yoffset;
 gint gridwidth;
 gint gridheight;
 
+gchar * warning_message = NULL;
+
 static void recalculate_sizes (gint width, gint height)
 {
   gdouble scale;
@@ -275,16 +277,26 @@ static void recreate_tile_images (void)
     fg = games_preimage_render (tilepreimage, tilewidth*NUM_PATTERNS,
                                 tileheight*2, NULL);
     
-    /* If the preimage was bad, we'll want to get rid of it. */
-    if (fg == NULL){
+    /* Handle corrupt images that were not caught during preimage creation. */
+    if (fg == NULL) {
       g_object_unref (tilepreimage);
       tilepreimage = NULL;
+
+      g_free (warning_message);
+      warning_message = g_strdup (_("This image may be corrupt."));
     }  
   
+  } 
+
+  /* If there's a warning, display it. */
+  if (warning_message) {
+    mahjongg_theme_warning (warning_message);
+    g_free (warning_message);
+    warning_message = NULL;
   }
-  
+
   /* If there's no theme pixbuf, provide a blank one. */
-  if (fg == NULL){
+  if (fg == NULL) {
     fg = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, 
                          tilewidth*NUM_PATTERNS, tileheight*2);
     gdk_pixbuf_fill (fg, 0x00000000);
@@ -405,25 +417,35 @@ void load_images (gchar * file)
   
   filename = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP,
                                         temp, TRUE, NULL);
-
   g_free (temp);
 
-  if (filename == NULL) {
-    file = "mahjongg/postmodern.svg";
+  if (!filename) {
+
     filename = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP,
-                                          file, TRUE, NULL);
+					  "mahjongg/postmodern.svg", TRUE, NULL);
+
+    if (!filename) {
+      warning_message = g_strdup_printf (_("Unable to locate file: '%s'\n\nAlso, the default tile set could not be found."), file);
+    } else {
+      warning_message = g_strdup_printf (_("Unable to locate file: '%s'\n\nThe default tile set will be loaded instead."), file);
+    }
+
   }
 
-  if (filename == NULL) {
-      /* FIXME: Put a warning dialog in here. */
-    g_warning ("Unable to load file %s\n", file);
-#if 0
-    error = g_error_new (G_FILE_ERROR, G_FILE_ERROR_NOENT,
-                         _("Unable to locate theme file: %s"), file);
-#endif
-  } else {
-    if (tilepreimage) g_object_unref (tilepreimage);
-    tilepreimage = games_preimage_new_from_uri (filename, NULL);
+  if (tilepreimage) 
+    g_object_unref (tilepreimage);
+
+  tilepreimage = NULL;
+  
+  if (filename) {
+    tilepreimage = games_preimage_new_from_file (filename, NULL);
+
+    /* This usually happens with bad images or a missing image loader. */
+    if (!tilepreimage) {
+      g_free (warning_message);
+      warning_message = g_strdup_printf (_("Unable to load file: '%s'\n\nThis tile set was found but did not load."), file);
+    }
+
   }
   
   update_tileimages = TRUE;
@@ -431,6 +453,7 @@ void load_images (gchar * file)
   if (tileset)
     g_free (tileset);
   tileset = g_strdup (file);
+
   g_free (filename);
 
   /* We may be called before the window is created, in which case we let
