@@ -196,6 +196,31 @@ GnomeUIInfo toolbar_uiinfo [] = {
 #define PAUSE_BUTTON GTK_TOGGLE_BUTTON(toolbar_uiinfo[2].widget)
 #define HIGHSCORE_WIDGET gamemenu[8].widget
 
+void mahjongg_theme_warning (gchar *message)
+{
+	GtkWidget *dialog;
+	GtkWidget *button;
+
+	dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+					 GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_MESSAGE_WARNING,
+					 GTK_BUTTONS_CLOSE,
+					 _("Could not load tile set"));
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), message);
+
+	button = gtk_dialog_add_button (GTK_DIALOG (dialog),
+					_("Preferences"), GTK_RESPONSE_ACCEPT
+					);
+
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+
+	g_signal_connect (button, "clicked", G_CALLBACK (properties_callback), NULL);
+
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+}
+
+
 /* At the end of the game, hint, shuffle and pause all become unavailable. */
 /* Undo and Redo are handled elsewhere. */
 static void set_menus_sensitive (void)
@@ -1430,9 +1455,11 @@ main (int argc, char *argv [])
 	if (!games_gconf_sanity_check_string (conf_client, "/apps/mahjongg/tileset")) {
 		return 1;
 	}
-	load_preferences ();
 	
 	window = gnome_app_new (APPNAME, _(APPNAME_LONG));
+
+        load_preferences ();
+        
 	gtk_window_set_default_size (GTK_WINDOW (window), windowwidth,
 				     windowheight);
 	gtk_window_set_title (GTK_WINDOW (window), _("Mahjongg"));
