@@ -132,18 +132,20 @@ gboolean expose_cb (GtkWidget *canvas, GdkEventExpose *event, gpointer data)
 			}
 		}
 
-		/* FIXME: These checks are wrong. */
-		if ((event->area.y + event->area.height) == board_height) {
+		/* Fixup the left and bottom lines. */
+		if ((event->area.y + event->area.height + 1) >= board_height*tile_size) {
 			/* FIXME: This should have it's own gc. */
 			gdk_draw_line (canvas->window, canvas->style->white_gc,
-										 event->area.x, board_height, 
-										 event->area.x + event->area.width, board_height);
+										 event->area.x, board_height*tile_size - 1, 
+										 event->area.x + event->area.width - 2, 
+										 board_height*tile_size - 1);
 		}
-		if ((event->area.x + event->area.width) == board_width) {
+		if ((event->area.x + event->area.width + 1) >= board_width*tile_size) {
 			/* FIXME: This should have it's own gc. */
 			gdk_draw_line (canvas->window, canvas->style->white_gc,
-										 board_width, event->area.y,
-										 board_width, event->area.y + event->area.height);
+										 board_width*tile_size - 1, event->area.y,
+										 board_width*tile_size - 1, 
+										 event->area.y + event->area.height - 2);
 		}
 
 	} else { /* Draw only the grid. */
@@ -214,6 +216,9 @@ static gboolean render_cb (GtkWidget *canvas)
 	guchar *p, *bp;
 	guint shift;
 	gchar *filename;
+	gchar *substring;
+	gchar *suffix;
+	gint length;
 	GtkWidget *dialog;
 
 	if (idle_state == INIT) {
@@ -257,8 +262,11 @@ static gboolean render_cb (GtkWidget *canvas)
 										 0, 0, 0, 0, tile_size, tile_size, GDK_RGB_DITHER_NORMAL,
 										 0, 0);
 
-		/* FIXME: We should also look for different suffices, e.g.
-		 * in case of a .png -> .svg changeover. */
+		/* This code is far from perfect. For starters it only checks to
+			 see if the file exists before deciding that the filename is the
+			 correct one. For example, if the user's copy of a file is
+			 corrupt, it should move onto the system one. */
+
 		/* First look in the players home directory. */
 		filename = g_build_filename (localthemedir, theme, NULL);
 		if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
@@ -266,12 +274,30 @@ static gboolean render_cb (GtkWidget *canvas)
 			/* Then look in the system directory. */
 			filename = g_build_filename (THEMEDIR, theme, NULL);
 			if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
-				g_free (filename);
-				/* And finallyy fall back to the default. */
-				filename = g_build_filename (THEMEDIR, DEFAULT_THEME, NULL);			
+				/* Some old themes had a -sync just before the suffix. This was
+				 * hidden from the user and has been eliminated from the names
+				 * of reworked themes. Check in case we had one of this form. */
+				length = strlen (filename);
+				substring = g_strstr_len (filename, length, "-sync");
+				suffix = g_strrstr (filename, ".png");
+				if (substring && suffix) {
+					g_stpcpy (substring, suffix);
+				}
+				if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
+					/* We have changed some themes from .png to .svg, try that. */
+					suffix = g_strrstr (filename, ".png");
+					if (suffix) {
+						g_stpcpy (suffix, ".svg");
+					}
+					if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
+							/* And finally fall back to the default. */
+							g_free (filename);
+							filename = g_build_filename (THEMEDIR, DEFAULT_THEME, NULL);
+					}
+				}
 			}
 		}
-
+		
 		file_pixbuf = gdk_pixbuf_new_from_file_at_size (filename,
 																										ftile_size*NFRAMESSPIN,
 																										ftile_size*MAX_COLOURS,
